@@ -17,7 +17,8 @@ def test_something():
         binary_invert,\
         split_touching_objects,\
         connected_component_labeling,\
-        seeded_watershed,\
+        seeded_watershed, \
+        seeded_watershed_with_mask, \
         voronoi_otsu_labeling, \
         gauss_otsu_labeling,\
         gaussian_laplace,\
@@ -84,6 +85,8 @@ def test_something():
 
     skeletonize(image > 0)
 
+    seeded_watershed_with_mask(image, image, image)
+
 def test_remove_labels_on_edges_sequential_labeling():
     image = np.asarray([
         [1,2,3],
